pub(in protocol::external) enum AddrV2 {
IpAddr {
untrusted_last_seen: DateTime32,
untrusted_services: PeerServices,
addr: PeerSocketAddr,
},
Unsupported,
}Expand description
The second format used for Bitcoin node addresses.
Contains a node address, its advertised services, and last-seen time.
This struct is serialized and deserialized into addrv2 messages.
Variants
IpAddr
An IPv4 or IPv6 node address, in addrv2 format.
Fields
untrusted_last_seen: DateTime32The unverified “last seen time” gossiped by the remote peer that sent us this address.
See the MetaAddr::last_seen method for details.
untrusted_services: PeerServicesThe unverified services for the peer at ip_addr:port.
These services were advertised by the peer at that address, then gossiped via another peer.
Security
untrusted_services on gossiped peers may be invalid due to outdated
records, older peer versions, or buggy or malicious peers.
addr: PeerSocketAddrThe peer’s canonical IP address and port.
Unlike AddrV1, this can be an IPv4 or IPv6 address.
Unsupported
A node address with an unsupported networkID, in addrv2 format.
Implementations
Sourceimpl AddrV2
impl AddrV2
Sourcefn ip_addr_from_bytes<const IP_ADDR_SIZE: usize>(
addr_bytes: Vec<u8>,
) -> Result<IpAddr, SerializationError>
fn ip_addr_from_bytes<const IP_ADDR_SIZE: usize>( addr_bytes: Vec<u8>, ) -> Result<IpAddr, SerializationError>
Deserialize addr_bytes as an IPv4 or IPv6 address, using the addrv2 format.
Returns the corresponding IpAddr.
The returned IP version is chosen based on IP_ADDR_SIZE,
which should be ADDR_V2_IPV4_ADDR_SIZE or ADDR_V2_IPV6_ADDR_SIZE.